# Writing Docs for orchestrator-core

## Setting up Documentation Environment

1. Install flit `pip install flit` inside of the venv you will use for orch development.
1. Setup dev env for writing docs `flit install`.
1. Write some documentation by editing the markdown files in `orchestrator-core/docs/`
1. Build the documentation with `mkdocs serve`.
1. View the documentation by opening `orchestrator-core/site/index.html` in your browser.
